Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrUnexpectedEndOfInput = errors.New("unexpected end of input") ErrUnexpectedDoubleStar = errors.New("unexpected '**' token in the middle of the path") ErrUnexpectedToken = errors.New("unexpected token") ErrSubVariable = errors.New("sub variables are not allowed in thix context") )
Functions ¶
func ParseTemplate ¶
func ParseTemplate(s string) (*pmpb.PathTemplate, error)
ParseTemplate parses a path template string and returns a PathMatch object or an error if the template is invalid.
Types ¶
Click to show internal directories.
Click to hide internal directories.